@@ -66,6 +66,14 @@ class SageMakerRuntimeClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client/#close)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -91,7 +99,8 @@ class SageMakerRuntimeClient(BaseClient):
         TargetModel: str = ...,
         TargetVariant: str = ...,
         TargetContainerHostname: str = ...,
-        InferenceId: str = ...
+        InferenceId: str = ...,
+        EnableExplanations: str = ...
     ) -> InvokeEndpointOutputTypeDef:
         """
         After you deploy a model into production using Amazon SageMaker hosting
@@ -111,10 +120,13 @@ class SageMakerRuntimeClient(BaseClient):
         Accept: str = ...,
         CustomAttributes: str = ...,
         InferenceId: str = ...,
-        RequestTTLSeconds: int = ...
+        RequestTTLSeconds: int = ...,
+        InvocationTimeoutSeconds: int = ...
     ) -> InvokeEndpointAsyncOutputTypeDef:
         """
-        .
+        After you deploy a model into production using Amazon SageMaker hosting
+        services, your client applications use this API to get inferences from the model
+        hosted at the specified endpoint in an asynchronous manner.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint_async)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client/#invoke_endpoint_async)
