@@ -45,6 +45,7 @@ _OptionalInvokeEndpointAsyncInputRequestTypeDef = TypedDict(
         "CustomAttributes": str,
         "InferenceId": str,
         "RequestTTLSeconds": int,
+        "InvocationTimeoutSeconds": int,
     },
     total=False,
 )
@@ -61,6 +62,7 @@ InvokeEndpointAsyncOutputTypeDef = TypedDict(
     {
         "InferenceId": str,
         "OutputLocation": str,
+        "FailureLocation": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -82,6 +84,7 @@ _OptionalInvokeEndpointInputRequestTypeDef = TypedDict(
         "TargetVariant": str,
         "TargetContainerHostname": str,
         "InferenceId": str,
+        "EnableExplanations": str,
     },
     total=False,
 )
